'use strict';

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _toggle = require('../toggle');

var _toggle2 = _interopRequireDefault(_toggle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('toggle', function () {
  var defaultRule = 'default: rule';
  var optionA = 'option: a';
  var optionB = 'option: b';

  it('should handle an empty case', function () {
    var namespace = (0, _toggle2.default)('namespace', {});
    (0, _expect2.default)(namespace()).toEqual([]);
    (0, _expect2.default)(namespace('')).toEqual([]);
    (0, _expect2.default)(namespace(' ')).toEqual([]);
  });

  it('should always inject default even if no input passed', function () {
    var namespace = (0, _toggle2.default)('namespace', {
      default: defaultRule
    });
    (0, _expect2.default)(namespace()).toEqual([defaultRule]);
    (0, _expect2.default)(namespace('')).toEqual([defaultRule]);
    (0, _expect2.default)(namespace(' ')).toEqual([defaultRule]);
  });

  it('should handle any combination of inputs', function () {
    var namespace = (0, _toggle2.default)('namespace', {
      default: defaultRule,
      a: optionA,
      b: optionB
    });
    (0, _expect2.default)(namespace()).toEqual([defaultRule]);
    (0, _expect2.default)(namespace('a')).toEqual([defaultRule, optionA]);
    (0, _expect2.default)(namespace('a b')).toEqual([defaultRule, optionA, optionB]);
    (0, _expect2.default)(namespace('b a')).toEqual([defaultRule, optionB, optionA]);
    (0, _expect2.default)(namespace('b')).toEqual([defaultRule, optionB]);
  });

  it('should be ok without a default', function () {
    var namespace = (0, _toggle2.default)('namespace', {
      a: optionA,
      b: optionB
    });
    (0, _expect2.default)(namespace()).toEqual([]);
    (0, _expect2.default)(namespace('a')).toEqual([optionA]);
    (0, _expect2.default)(namespace('a b')).toEqual([optionA, optionB]);
    (0, _expect2.default)(namespace('b a')).toEqual([optionB, optionA]);
    (0, _expect2.default)(namespace('b')).toEqual([optionB]);
  });

  it('should throw if passed something not present', function () {
    var namespace = (0, _toggle2.default)('namespace', {
      a: optionA
    });
    (0, _expect2.default)(function () {
      return namespace('b');
    }).toThrow("namespace: Unknown value 'b'. Valid values are:\na");
  });

  it('should not mention the default as a valid', function () {
    var namespace = (0, _toggle2.default)('namespace', {
      default: defaultRule,
      a: optionA
    });
    (0, _expect2.default)(function () {
      return namespace('b');
    }).toThrow("namespace: Unknown value 'b'. Valid values are:\na");
  });
});